==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork.md <==
# AmazonBraketTensorNetwork


```text
aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork
```

```text
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')
```



| Illustration | AmazonBraketTensorNetwork | AmazonBraketTensorNetworkCard | AmazonBraketTensorNetworkGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork.png) | ![illustration for AmazonBraketTensorNetwork](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork.Local.png) | ![illustration for AmazonBraketTensorNetworkCard](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetworkCard.Local.png) | ![illustration for AmazonBraketTensorNetworkGroup](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetworkGroup.Local.png) |




## AmazonBraketTensorNetwork

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetwork
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetwork('AmazonBraketTensorNetwork', 'Amazon Braket Tensor Network', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetwork
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetwork('AmazonBraketTensorNetwork', 'Amazon Braket Tensor Network', 'an optional tech label')
@enduml
```

## AmazonBraketTensorNetworkCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkCard('AmazonBraketTensorNetworkCard', 'Amazon Braket Tensor Network Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkCard('AmazonBraketTensorNetworkCard', 'Amazon Braket Tensor Network Card', 'an optional description')
@enduml
```

## AmazonBraketTensorNetworkGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkGroup('AmazonBraketTensorNetworkGroup', 'Amazon Braket Tensor Network Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkGroup('AmazonBraketTensorNetworkGroup', 'Amazon Braket Tensor Network Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork.md <==
# AmazonBraketTensorNetwork


```text
aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork
```

```text
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')
```



| Illustration | AmazonBraketTensorNetwork | AmazonBraketTensorNetworkCard | AmazonBraketTensorNetworkGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork.png) | ![illustration for AmazonBraketTensorNetwork](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork.Local.png) | ![illustration for AmazonBraketTensorNetworkCard](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetworkCard.Local.png) | ![illustration for AmazonBraketTensorNetworkGroup](../../../aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetworkGroup.Local.png) |




## AmazonBraketTensorNetwork

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetwork
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetwork('AmazonBraketTensorNetwork', 'Amazon Braket Tensor Network', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetwork
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetwork('AmazonBraketTensorNetwork', 'Amazon Braket Tensor Network', 'an optional tech label')
@enduml
```

## AmazonBraketTensorNetworkCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkCard('AmazonBraketTensorNetworkCard', 'Amazon Braket Tensor Network Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkCard
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkCard('AmazonBraketTensorNetworkCard', 'Amazon Braket Tensor Network Card', 'an optional description')
@enduml
```

## AmazonBraketTensorNetworkGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkGroup('AmazonBraketTensorNetworkGroup', 'Amazon Braket Tensor Network Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonBraketTensorNetworkGroup
include('aws-q3-2021/Resource/QuantumTechnologies/AmazonBraketTensorNetwork')

' renders the element
AmazonBraketTensorNetworkGroup('AmazonBraketTensorNetworkGroup', 'Amazon Braket Tensor Network Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
